%define upstream_name	CPAN
%define upstream_version 2.34

%{?perl_default_filter}
# Filter non-Linux dependencies
%global __requires_exclude %{?__requires_exclude:%__requires_exclude|}^perl\\(Mac::BuildTools\\)
# Filter under-specified dependencies
%global __requires_exclude %{?__requires_exclude:%__requires_exclude|}^perl\\(CPAN::Meta::Requirements\\)

Name:       perl-%{upstream_name}
Version:    %perl_convert_version %{upstream_version}
Release:    %mkrel 1
Epoch:      1

Summary:    %{upstream_name} module for perl
License:    GPL+ or Artistic
Group:      Development/Perl
Url:        https://metacpan.org/release/%{upstream_name}
Source0:    https://cpan.metacpan.org/authors/id/A/AN/ANDK/%{upstream_name}-%{upstream_version}.tar.gz
# Create site paths for the first time, bug #1158873, CPAN RT#99905
Patch0:     CPAN-2.18-Attemp-to-create-site-library-directories-on-first-t.patch
# Change configuration directory name
Patch1:     CPAN-2.18-Replace-configuration-directory-string-with-a-marke.patch
# Enable loading objects from session YAML files, CPAN RT#131615
# <https://github.com/andk/cpanpm/pull/133>

BuildRequires: perl(Archive::Tar)
BuildRequires: perl(Archive::Zip)
BuildRequires: perl(CPAN::Checksums)
BuildRequires: perl(CPAN::Meta)
BuildRequires: perl(CPAN::Meta::Requirements) >= 2.121.0
BuildRequires: perl(CPAN::Meta::YAML)
BuildRequires: perl(CPAN::Perl::Releases)
BuildRequires: perl(Compress::Bzip2)
BuildRequires: perl(Compress::Zlib)
BuildRequires: perl(Data::Dumper)
BuildRequires: perl(Digest::MD5)
BuildRequires: perl(Digest::SHA)
BuildRequires: perl(Expect)
BuildRequires: perl(Exporter)
BuildRequires: perl(Exporter::Heavy)
BuildRequires: perl(ExtUtils::CBuilder)
BuildRequires: perl(ExtUtils::MakeMaker)
BuildRequires: perl(File::Copy)
BuildRequires: perl(File::HomeDir)
BuildRequires: perl(File::Spec)
BuildRequires: perl(File::Temp)
BuildRequires: perl(File::Which)
BuildRequires: perl(HTTP::Tiny)
BuildRequires: perl(IO::Compress::Base)
BuildRequires: perl(IO::Zlib)
BuildRequires: perl(JSON::PP)
BuildRequires: perl(LWP::UserAgent)
BuildRequires: perl(Log::Log4perl)
BuildRequires: perl(MIME::Base64)
BuildRequires: perl(Module::Build)
BuildRequires: perl(Module::Signature)
BuildRequires: perl(Net::FTP)
BuildRequires: perl(Net::Ping)
BuildRequires: perl(Parse::CPAN::Meta)
BuildRequires: perl(Pod::Perldoc)
BuildRequires: perl(Pod::Perldoc::ToMan)
BuildRequires: perl(Scalar::Util)
BuildRequires: perl(Socket)
BuildRequires: perl(Term::ReadKey)
BuildRequires: perl(Test::Harness) >= 2.620.0
BuildRequires: perl(Test::More)
BuildRequires: perl(Text::Glob)
BuildRequires: perl(Text::ParseWords)
BuildRequires: perl(Text::Wrap)
BuildRequires: perl(YAML)
BuildRequires: perl(YAML::Syck)
BuildRequires: perl(YAML::XS)
BuildArch:  noarch

Obsoletes:  cpan <= 1.590.200
Provides:   cpan

%description
The CPAN module automates or at least simplifies the make and install of
perl modules and extensions. It includes some primitive searching
capabilities and knows how to use Net::FTP or LWP or some external
download clients to fetch the distributions from the net.

These are fetched from one or more of the mirrored CPAN (Comprehensive
Perl Archive Network) sites and unpacked in a dedicated directory.

The CPAN module also supports the concept of named and versioned
*bundles* of modules. Bundles simplify the handling of sets of related
modules. See Bundles below.

The package contains a session manager and a cache manager. The session
manager keeps track of what has been fetched, built and installed in the
current session. The cache manager keeps track of the disk space
occupied by the make processes and deletes excess space according to a
simple FIFO mechanism.

All methods provided are accessible in a programmer style and in an
interactive shell style.

%prep
%setup -q -n %{upstream_name}-%{upstream_version}
%autopatch -p1

%build
%__perl Makefile.PL INSTALLDIRS=vendor
%make_build

%install
%make_install
for i in %{buildroot}/%{_bindir}/*; do mv $i $i-%{upstream_version}; done

%check
unset AUTHOR_TEST CPAN_EXPECT_TIMEOUT CPAN_RUN_SHELL_TEST_WITHOUT_EXPECT \
    ftp_proxy http_proxy no_proxy \
    PERL5_CPAN_IS_RUNNING PERL5_CPAN_IS_RUNNING_IN_RECURSION PERL_CORE VERBOSE
make test

%files
%doc Changes META.json META.yml MYMETA.yml README SIGNATURE
%{_bindir}/*
%{_mandir}/*/*
%{perl_vendorlib}

%changelog
* Tue Apr 19 2022 tv <tv> 1:2.340.0-1.mga9
+ Revision: 1851562
- update to 2.34

* Mon Mar 28 2022 tv <tv> 1:2.330.0-1.mga9
+ Revision: 1829804
- update to 2.33

* Wed Mar 23 2022 umeabot <umeabot> 1:2.290.0-2.mga9
+ Revision: 1820946
- Mageia 9 Mass Rebuild

* Fri Nov 26 2021 tv <tv> 1:2.290.0-1.mga9
+ Revision: 1759540
- update to 2.29

* Sat Jun 13 2020 shlomif <shlomif> 1:2.280.0-1.mga8
+ Revision: 1593172
- update to 2.28

* Sun Feb 16 2020 tv <tv> 1:2.270.0-2.mga8
+ Revision: 1529815
- fix testsuite failures
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild

* Thu Jul 04 2019 tv <tv> 1:2.270.0-1.mga8
+ Revision: 1418218
- update to 2.27

* Tue Mar 19 2019 tv <tv> 1:2.260.0-1.mga7
+ Revision: 1378761
- update to 2.26

* Fri Mar 15 2019 tv <tv> 1:2.250.0-1.mga7
+ Revision: 1377477
- update to 2.25

* Fri Dec 28 2018 tv <tv> 1:2.220.0-1.mga7
+ Revision: 1345395
- update to 2.22

* Thu Sep 20 2018 umeabot <umeabot> 1:2.160.0-2.mga7
+ Revision: 1281860
- Mageia 7 Mass Rebuild

* Mon Jul 31 2017 sander85 <sander85> 1:2.160.0-1.mga7
+ Revision: 1133000
- update to 2.16

* Sat Jun 18 2016 pterjan <pterjan> 1:2.100.0-3.mga6
+ Revision: 1024412
- Rebuild for perl 5.22.2

* Thu Feb 18 2016 umeabot <umeabot> 1:2.100.0-2.mga6
+ Revision: 967401
- Mageia 6 Mass Rebuild

* Tue Jun 30 2015 sander85 <sander85> 1:2.100.0-1.mga6
+ Revision: 848786
- update to 2.10

* Wed Oct 15 2014 umeabot <umeabot> 1:2.50.0-7.mga5
+ Revision: 749429
- Second Mageia 5 Mass Rebuild

* Tue Sep 30 2014 tv <tv> 1:2.50.0-6.mga5
+ Revision: 732994
- add exclude

* Thu Sep 25 2014 tv <tv> 1:2.50.0-5.mga5
+ Revision: 724534
- add excludes

* Tue Sep 23 2014 tv <tv> 1:2.50.0-4.mga5
+ Revision: 722228
- use %%perl_default_filter

* Tue Sep 16 2014 umeabot <umeabot> 1:2.50.0-3.mga5
+ Revision: 683667
- Mageia 5 Mass Rebuild

* Fri Jun 06 2014 jquelin <jquelin> 1:2.50.0-2.mga5
+ Revision: 634163
- perl 5.20 rebuild

* Fri Apr 25 2014 jquelin <jquelin> 1:2.50.0-1.mga5
+ Revision: 617765
- update to 2.05

* Fri Apr 04 2014 jquelin <jquelin> 1:2.0.0-3.mga5
+ Revision: 611633
- Fed up with App::Cpan from b.d.foy, getting rid of it

* Mon Oct 21 2013 umeabot <umeabot> 1:2.0.0-2.mga4
+ Revision: 536985
- Mageia 4 Mass Rebuild

* Wed Sep 25 2013 sander85 <sander85> 1:2.0.0-1.mga4
+ Revision: 486096
- update to 2.00

* Fri Feb 15 2013 jquelin <jquelin> 1:1.980.0-4.mga3
+ Revision: 398543
- allow cpan and perl-CPAN to be installed in // (rt#82789)

* Sun Jan 13 2013 umeabot <umeabot> 1:1.980.0-3.mga3
+ Revision: 363602
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Fri Nov 04 2011 jquelin <jquelin> 1:1.980.0-2.mga2
+ Revision: 162787
- take priority over module bundled with perl 5.14.2
- update to 1.9800

* Sun Mar 13 2011 jquelin <jquelin> 1:1.960.0-1.mga1
+ Revision: 70624
- update to 1.9600

* Sat Jan 22 2011 jquelin <jquelin> 1:1.940.200-1.mga1
+ Revision: 31735
- mageia rebuild
- imported package perl-CPAN

